//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"'('",
	"')'",
	"';'",
	"'{'",
	"'}'",
	"']'",
	"'\"'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:1159
const src = `<?php
$a::test(null, $a);
`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 43,
	69, 407,
	133, 407,
	153, 407,
	162, 407,
	-2, 416,
	-1, 47,
	159, 410,
	-2, 439,
	-1, 83,
	69, 409,
	133, 409,
	153, 409,
	159, 412,
	162, 409,
	-2, 384,
	-1, 98,
	153, 405,
	-2, 401,
	-1, 210,
	69, 407,
	133, 407,
	153, 407,
	162, 407,
	-2, 313,
	-1, 213,
	159, 412,
	-2, 409,
	-1, 214,
	69, 407,
	133, 407,
	153, 407,
	162, 407,
	-2, 315,
	-1, 324,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 337,
	-1, 325,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 338,
	-1, 326,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 339,
	-1, 327,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 340,
	-1, 328,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 341,
	-1, 329,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 342,
	-1, 330,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 343,
	-1, 331,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 344,
	-1, 332,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 345,
	-1, 338,
	9, 214,
	160, 214,
	-2, 407,
	-1, 378,
	69, 408,
	133, 408,
	153, 408,
	159, 411,
	162, 408,
	-2, 346,
	-1, 383,
	159, 430,
	-2, 402,
	-1, 385,
	159, 432,
	-2, 448,
	-1, 463,
	159, 430,
	-2, 403,
	-1, 465,
	159, 432,
	-2, 449,
	-1, 487,
	9, 197,
	160, 197,
	164, 197,
	-2, 407,
	-1, 522,
	160, 277,
	-2, 282,
	-1, 540,
	159, 411,
	-2, 408,
	-1, 590,
	15, 185,
	160, 185,
	-2, 407,
	-1, 616,
	88, 256,
	-2, 262,
	-1, 639,
	9, 196,
	160, 196,
	164, 196,
	-2, 407,
	-1, 660,
	15, 186,
	160, 186,
	-2, 407,
	-1, 709,
	15, 188,
	160, 188,
	-2, 414,
	-1, 773,
	105, 76,
	-2, 78,
	-1, 790,
	160, 277,
	-2, 282,
}

const yyPrivate = 57344

const yyLast = 6682

var yyAct = [...]int{

	27, 122, 725, 713, 598, 98, 529, 618, 389, 765,
	724, 704, 740, 602, 675, 178, 118, 517, 527, 589,
	600, 129, 129, 129, 293, 103, 141, 571, 653, 285,
	642, 572, 4, 83, 175, 603, 107, 113, 524, 79,
	346, 255, 289, 480, 337, 8, 288, 124, 140, 7,
	286, 209, 120, 5, 215, 216, 217, 218, 219, 287,
	221, 222, 6, 224, 225, 226, 227, 228, 229, 230,
	231, 232, 233, 137, 234, 235, 236, 134, 257, 251,
	2, 709, 78, 117, 243, 213, 213, 626, 128, 43,
	384, 211, 211, 119, 634, 544, 556, 96, 374, 536,
	96, 484, 259, 262, 820, 821, 135, 266, 267, 812,
	131, 132, 774, 736, 733, 731, 692, 585, 557, 753,
	712, 741, 760, 721, 291, 672, 609, 295, 296, 528,
	263, 279, 265, 699, 700, 348, 96, 272, 174, 815,
	278, 210, 214, 489, 307, 308, 309, 310, 311, 312,
	313, 314, 315, 316, 317, 318, 319, 320, 321, 322,
	323, 324, 325, 326, 327, 328, 329, 330, 331, 332,
	333, 335, 244, 339, 375, 97, 341, 470, 97, 253,
	250, 622, 623, 624, 621, 620, 619, 109, 743, 268,
	555, 356, 358, 359, 360, 361, 362, 363, 364, 365,
	366, 367, 368, 369, 800, 213, 370, 129, 372, 489,
	249, 211, 489, 377, 97, 206, 352, 699, 700, 644,
	591, 379, 275, 306, 380, 615, 489, 794, 617, 622,
	623, 624, 621, 620, 619, 245, 246, 793, 129, 728,
	729, 383, 463, 780, 749, 813, 473, 801, 584, 476,
	477, 742, 593, 481, 744, 259, 604, 737, 106, 130,
	696, 338, 281, 108, 303, 301, 281, 340, 756, 109,
	275, 96, 698, 615, 759, 720, 617, 102, 685, 208,
	213, 657, 656, 504, 659, 575, 211, 748, 569, 654,
	279, 376, 652, 649, 213, 371, 483, 508, 4, 496,
	211, 499, 500, 493, 490, 513, 354, 141, 207, 343,
	299, 8, 109, 298, 747, 7, 719, 592, 100, 5,
	297, 385, 465, 269, 738, 467, 382, 469, 6, 732,
	464, 667, 469, 467, 503, 516, 475, 125, 641, 637,
	104, 587, 212, 797, 576, 562, 264, 790, 491, 97,
	487, 711, 531, 526, 532, 514, 530, 533, 534, 497,
	661, 606, 607, 640, 109, 252, 522, 507, 145, 147,
	146, 505, 239, 717, 494, 305, 539, 512, 109, 511,
	125, 488, 543, 104, 135, 277, 523, 353, 169, 546,
	170, 143, 144, 148, 150, 149, 162, 163, 160, 161,
	164, 165, 166, 167, 168, 158, 159, 152, 153, 151,
	154, 156, 157, 520, 101, 277, 302, 300, 280, 351,
	109, 130, 274, 254, 223, 220, 155, 606, 607, 658,
	205, 109, 125, 96, 173, 104, 172, 262, 171, 102,
	127, 126, 123, 105, 277, 106, 125, 115, 116, 104,
	262, 277, 109, 538, 622, 623, 624, 621, 620, 619,
	277, 238, 525, 347, 545, 471, 109, 570, 350, 795,
	665, 666, 678, 677, 796, 112, 244, 676, 109, 292,
	100, 248, 244, 561, 76, 77, 259, 564, 635, 259,
	784, 114, 244, 745, 699, 700, 502, 559, 615, 125,
	242, 617, 104, 495, 212, 115, 116, 755, 580, 295,
	582, 97, 276, 244, 138, 279, 586, 573, 470, 109,
	244, 4, 687, 498, 499, 240, 499, 553, 605, 472,
	567, 530, 610, 581, 8, 180, 578, 273, 7, 245,
	246, 681, 5, 783, 547, 245, 246, 625, 121, 501,
	595, 6, 213, 213, 466, 245, 246, 636, 211, 211,
	489, 481, 608, 588, 563, 630, 702, 699, 700, 622,
	623, 624, 621, 620, 619, 468, 245, 246, 345, 551,
	344, 650, 241, 245, 246, 184, 643, 271, 183, 645,
	182, 647, 573, 176, 259, 499, 247, 237, 663, 213,
	499, 499, 155, 648, 638, 211, 185, 186, 338, 590,
	605, 179, 670, 615, 655, 549, 617, 552, 550, 714,
	45, 530, 679, 684, 680, 213, 355, 787, 673, 177,
	761, 211, 682, 686, 722, 662, 187, 189, 188, 304,
	671, 259, 622, 623, 624, 621, 620, 619, 154, 156,
	157, 282, 626, 295, 690, 639, 611, 683, 181, 574,
	689, 643, 259, 573, 155, 646, 694, 668, 560, 518,
	499, 111, 499, 509, 605, 691, 485, 697, 693, 707,
	1, 660, 688, 701, 80, 703, 730, 99, 705, 715,
	479, 718, 349, 213, 726, 110, 270, 373, 48, 211,
	739, 49, 82, 708, 81, 548, 72, 734, 746, 735,
	819, 768, 769, 767, 752, 766, 499, 751, 764, 727,
	605, 614, 723, 758, 674, 616, 613, 612, 754, 762,
	664, 750, 771, 597, 594, 770, 757, 258, 256, 336,
	139, 136, 779, 133, 583, 775, 294, 577, 15, 590,
	42, 14, 778, 41, 47, 786, 44, 599, 601, 782,
	37, 283, 789, 3, 387, 716, 669, 771, 776, 0,
	770, 788, 0, 0, 792, 0, 0, 705, 0, 798,
	799, 0, 0, 0, 0, 0, 0, 0, 804, 0,
	802, 0, 0, 0, 0, 805, 605, 0, 0, 0,
	810, 530, 806, 0, 809, 808, 0, 0, 0, 145,
	147, 146, 814, 0, 816, 0, 0, 817, 396, 397,
	398, 399, 400, 822, 401, 402, 403, 439, 440, 169,
	741, 170, 143, 144, 148, 150, 149, 162, 163, 160,
	161, 164, 165, 166, 167, 168, 158, 159, 152, 153,
	151, 154, 156, 157, 165, 166, 167, 168, 158, 159,
	152, 153, 151, 154, 156, 157, 0, 155, 0, 0,
	404, 0, 0, 0, 0, 0, 0, 0, 0, 155,
	0, 0, 0, 0, 405, 406, 0, 409, 410, 411,
	390, 391, 392, 393, 394, 395, 407, 408, 0, 0,
	386, 0, 96, 0, 0, 0, 0, 0, 0, 412,
	413, 414, 415, 416, 417, 418, 419, 420, 421, 422,
	442, 443, 444, 445, 446, 434, 435, 436, 437, 438,
	423, 424, 425, 426, 427, 428, 429, 430, 431, 432,
	433, 0, 454, 452, 453, 449, 450, 0, 441, 447,
	448, 455, 456, 458, 457, 459, 460, 0, 0, 0,
	742, 0, 59, 60, 61, 62, 63, 0, 451, 462,
	461, 73, 74, 0, 75, 0, 388, 0, 0, 0,
	97, 148, 150, 149, 162, 163, 160, 161, 164, 165,
	166, 167, 168, 158, 159, 152, 153, 151, 154, 156,
	157, 0, 0, 0, 0, 0, 0, 53, 54, 0,
	0, 0, 0, 55, 155, 56, 51, 52, 64, 65,
	66, 67, 68, 69, 70, 71, 0, 101, 0, 50,
	0, 0, 0, 0, 24, 76, 77, 0, 0, 0,
	0, 46, 84, 85, 35, 0, 96, 0, 26, 0,
	0, 0, 102, 25, 17, 16, 0, 18, 0, 29,
	0, 30, 0, 0, 19, 0, 0, 0, 20, 21,
	34, 36, 12, 22, 32, 0, 0, 33, 11, 0,
	23, 0, 28, 0, 58, 9, 38, 39, 40, 0,
	0, 0, 0, 100, 0, 93, 89, 90, 91, 86,
	87, 0, 0, 0, 0, 0, 0, 94, 0, 0,
	0, 0, 10, 92, 88, 104, 0, 57, 146, 31,
	13, 568, 0, 95, 97, 59, 60, 61, 62, 63,
	0, 0, 0, 0, 73, 74, 169, 75, 170, 143,
	144, 148, 150, 149, 162, 163, 160, 161, 164, 165,
	166, 167, 168, 158, 159, 152, 153, 151, 154, 156,
	157, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	53, 54, 0, 0, 155, 0, 55, 0, 56, 51,
	52, 64, 65, 66, 67, 68, 69, 70, 71, 0,
	101, 0, 50, 0, 0, 0, 0, 24, 76, 77,
	0, 0, 0, 0, 46, 84, 85, 35, 0, 96,
	0, 26, 0, 0, 0, 102, 25, 17, 16, 0,
	18, 0, 29, 0, 30, 0, 0, 19, 0, 0,
	0, 20, 21, 34, 36, 12, 22, 32, 0, 0,
	33, 11, 0, 23, 0, 28, 0, 58, 9, 38,
	39, 40, 0, 0, 0, 0, 100, 0, 93, 89,
	90, 91, 86, 87, 0, 0, 0, 0, 0, 0,
	94, 0, 0, 0, 0, 10, 92, 88, 104, 0,
	57, 0, 31, 13, 492, 0, 95, 97, 59, 60,
	61, 62, 63, 0, 0, 0, 0, 73, 74, 169,
	75, 170, 143, 144, 148, 150, 149, 162, 163, 160,
	161, 164, 165, 166, 167, 168, 158, 159, 152, 153,
	151, 154, 156, 157, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 53, 54, 0, 0, 155, 0, 55,
	0, 56, 51, 52, 64, 65, 66, 67, 68, 69,
	70, 71, 0, 101, 0, 50, 0, 0, 0, 0,
	24, 76, 77, 0, 0, 0, 0, 46, 84, 85,
	35, 0, 96, 0, 26, 0, 0, 0, 102, 25,
	17, 16, 0, 18, 0, 29, 0, 30, 0, 0,
	19, 0, 0, 0, 20, 21, 34, 36, 12, 22,
	32, 0, 0, 33, 11, 0, 23, 0, 28, 0,
	58, 9, 38, 39, 40, 0, 0, 0, 0, 100,
	0, 93, 89, 90, 91, 86, 87, 0, 0, 0,
	0, 0, 0, 94, 0, 0, 0, 0, 10, 92,
	88, 104, 0, 57, 0, 31, 13, 381, 0, 95,
	97, 59, 60, 61, 62, 63, 0, 0, 0, 0,
	73, 74, 169, 75, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 53, 54, 0, 0,
	155, 0, 55, 0, 56, 51, 52, 64, 65, 66,
	67, 68, 69, 70, 71, 0, 101, 0, 50, 0,
	0, 0, 0, 24, 76, 77, 0, 0, 0, 0,
	46, 84, 85, 35, 0, 96, 0, 26, 0, 0,
	0, 102, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 0, 22, 32, 0, 0, 33, 0, 0, 23,
	0, 28, 0, 58, 290, 38, 39, 40, 0, 0,
	0, 0, 100, 0, 93, 89, 90, 91, 86, 87,
	0, 0, 0, 0, 0, 0, 94, 0, 0, 0,
	0, 125, 92, 88, 104, 0, 57, 0, 31, 13,
	823, 0, 95, 97, 59, 60, 61, 62, 63, 0,
	0, 0, 0, 73, 74, 0, 75, 170, 143, 144,
	148, 150, 149, 162, 163, 160, 161, 164, 165, 166,
	167, 168, 158, 159, 152, 153, 151, 154, 156, 157,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 155, 0, 55, 0, 56, 51, 52,
	64, 65, 66, 67, 68, 69, 70, 71, 0, 101,
	0, 50, 0, 0, 0, 0, 24, 76, 77, 0,
	0, 0, 0, 46, 84, 85, 35, 0, 96, 0,
	26, 0, 0, 0, 102, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 36, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 0, 58, 290, 38, 39,
	40, 0, 0, 0, 0, 100, 0, 93, 89, 90,
	91, 86, 87, 0, 0, 0, 0, 0, 0, 94,
	0, 0, 0, 0, 125, 92, 88, 104, 0, 57,
	0, 31, 13, 818, 0, 95, 97, 59, 60, 61,
	62, 63, 0, 0, 0, 0, 73, 74, 0, 75,
	144, 148, 150, 149, 162, 163, 160, 161, 164, 165,
	166, 167, 168, 158, 159, 152, 153, 151, 154, 156,
	157, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 53, 54, 155, 0, 0, 0, 55, 0,
	56, 51, 52, 64, 65, 66, 67, 68, 69, 70,
	71, 0, 101, 0, 50, 0, 0, 0, 0, 24,
	76, 77, 0, 0, 0, 0, 46, 84, 85, 35,
	0, 96, 0, 26, 0, 0, 0, 102, 25, 17,
	16, 0, 18, 811, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 36, 0, 22, 32,
	0, 0, 33, 0, 0, 23, 0, 28, 0, 58,
	290, 38, 39, 40, 0, 0, 0, 0, 100, 0,
	93, 89, 90, 91, 86, 87, 0, 0, 0, 0,
	0, 0, 94, 0, 0, 0, 0, 125, 92, 88,
	104, 0, 57, 0, 31, 13, 0, 0, 95, 97,
	59, 60, 61, 62, 63, 0, 0, 0, 0, 73,
	74, 0, 75, 0, 0, 150, 149, 162, 163, 160,
	161, 164, 165, 166, 167, 168, 158, 159, 152, 153,
	151, 154, 156, 157, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 53, 54, 155, 0, 0,
	0, 55, 0, 56, 51, 52, 64, 65, 66, 67,
	68, 69, 70, 71, 0, 101, 0, 50, 0, 0,
	0, 0, 24, 76, 77, 0, 0, 0, 0, 46,
	84, 85, 35, 0, 96, 0, 26, 0, 0, 0,
	102, 25, 17, 16, 0, 18, 0, 29, 0, 30,
	0, 0, 19, 0, 0, 0, 20, 21, 34, 36,
	0, 22, 32, 0, 0, 33, 0, 0, 23, 0,
	28, 0, 58, 290, 38, 39, 40, 0, 0, 0,
	0, 100, 0, 93, 89, 90, 91, 86, 87, 0,
	0, 0, 0, 0, 0, 94, 0, 0, 0, 0,
	125, 92, 88, 104, 0, 57, 0, 31, 13, 803,
	0, 95, 97, 396, 397, 398, 399, 400, 0, 401,
	402, 403, 439, 440, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 158, 159, 152, 153, 151, 154, 156, 157,
	0, 0, 0, 0, 0, 155, 152, 153, 151, 154,
	156, 157, 0, 155, 0, 404, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 155, 0, 0, 0, 405,
	406, 0, 409, 410, 411, 390, 391, 392, 393, 394,
	395, 407, 408, 0, 0, 773, 0, 0, 0, 0,
	0, 0, 0, 0, 412, 413, 414, 415, 416, 417,
	418, 419, 420, 421, 422, 442, 443, 444, 445, 446,
	434, 435, 436, 437, 438, 423, 424, 425, 426, 427,
	428, 429, 430, 431, 432, 433, 0, 454, 452, 453,
	449, 450, 0, 441, 447, 448, 455, 456, 458, 457,
	459, 460, 0, 0, 0, 0, 0, 0, 59, 60,
	61, 62, 63, 772, 462, 461, 104, 73, 74, 0,
	75, 0, 791, 0, 0, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 53, 54, 155, 0, 0, 0, 55,
	0, 56, 51, 52, 64, 65, 66, 67, 68, 69,
	70, 71, 0, 101, 0, 50, 0, 0, 0, 0,
	24, 76, 77, 0, 0, 0, 0, 46, 84, 85,
	35, 0, 96, 0, 26, 0, 0, 0, 102, 25,
	17, 16, 0, 18, 0, 29, 0, 30, 0, 0,
	19, 0, 0, 0, 20, 21, 34, 36, 0, 22,
	32, 0, 0, 33, 0, 0, 23, 0, 28, 0,
	58, 290, 38, 39, 40, 0, 0, 0, 0, 100,
	0, 93, 89, 90, 91, 86, 87, 0, 0, 0,
	0, 0, 0, 94, 0, 0, 0, 0, 125, 92,
	88, 104, 0, 57, 0, 31, 13, 785, 0, 95,
	97, 59, 60, 61, 62, 63, 0, 0, 0, 0,
	73, 74, 0, 75, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 190, 191,
	192, 193, 195, 196, 197, 198, 199, 200, 201, 202,
	194, 0, 0, 0, 0, 0, 53, 54, 0, 0,
	0, 0, 55, 0, 56, 51, 52, 64, 65, 66,
	67, 68, 69, 70, 71, 0, 101, 0, 50, 203,
	204, 0, 0, 24, 76, 77, 0, 0, 0, 0,
	46, 84, 85, 35, 0, 96, 0, 26, 0, 0,
	0, 102, 25, 17, 16, 0, 18, 0, 29, 781,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 0, 22, 32, 0, 0, 33, 0, 0, 23,
	0, 28, 0, 58, 290, 38, 39, 40, 0, 0,
	0, 0, 100, 0, 93, 89, 90, 91, 86, 87,
	0, 0, 0, 0, 0, 0, 94, 0, 0, 0,
	0, 125, 92, 88, 104, 0, 57, 0, 31, 13,
	147, 146, 95, 97, 396, 397, 398, 399, 400, 0,
	401, 402, 403, 439, 440, 0, 0, 0, 0, 169,
	0, 170, 143, 144, 148, 150, 149, 162, 163, 160,
	161, 164, 165, 166, 167, 168, 158, 159, 152, 153,
	151, 154, 156, 157, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 404, 155, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	405, 406, 0, 409, 410, 411, 390, 391, 392, 393,
	394, 395, 407, 408, 0, 0, 773, 0, 0, 0,
	0, 0, 0, 0, 0, 412, 413, 414, 415, 416,
	417, 418, 419, 420, 421, 422, 442, 443, 444, 445,
	446, 434, 435, 436, 437, 438, 423, 424, 425, 426,
	427, 428, 429, 430, 431, 432, 433, 0, 454, 452,
	453, 449, 450, 0, 441, 447, 448, 455, 456, 458,
	457, 459, 460, 0, 0, 0, 0, 0, 0, 59,
	60, 61, 62, 63, 772, 462, 461, 104, 73, 74,
	0, 75, 0, 763, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 53, 54, 0, 0, 0, 0,
	55, 0, 56, 51, 52, 64, 65, 66, 67, 68,
	69, 70, 71, 0, 101, 0, 50, 0, 0, 0,
	0, 24, 76, 77, 0, 0, 0, 0, 46, 84,
	85, 35, 0, 96, 0, 26, 0, 0, 0, 102,
	25, 17, 16, 0, 18, 0, 29, 0, 30, 710,
	0, 19, 0, 0, 0, 20, 21, 34, 36, 0,
	22, 32, 0, 0, 33, 0, 0, 23, 0, 28,
	0, 58, 290, 38, 39, 40, 0, 0, 0, 0,
	100, 0, 93, 89, 90, 91, 86, 87, 0, 0,
	0, 0, 0, 0, 94, 0, 0, 0, 0, 125,
	92, 88, 104, 0, 57, 0, 31, 13, 0, 0,
	95, 97, 59, 60, 61, 62, 63, 0, 0, 0,
	0, 73, 74, 0, 75, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 53, 54, 0,
	0, 0, 0, 55, 0, 56, 51, 52, 64, 65,
	66, 67, 68, 69, 70, 71, 0, 101, 0, 50,
	0, 0, 0, 0, 24, 76, 77, 0, 0, 0,
	0, 46, 84, 85, 35, 0, 96, 0, 26, 0,
	0, 0, 102, 25, 17, 16, 695, 18, 0, 29,
	0, 30, 0, 0, 19, 0, 0, 0, 20, 21,
	34, 36, 0, 22, 32, 0, 0, 33, 0, 0,
	23, 0, 28, 0, 58, 290, 38, 39, 40, 0,
	0, 0, 0, 100, 0, 93, 89, 90, 91, 86,
	87, 0, 0, 0, 0, 0, 0, 94, 0, 0,
	0, 0, 125, 92, 88, 104, 0, 57, 0, 31,
	13, 0, 0, 95, 97, 59, 60, 61, 62, 63,
	0, 0, 0, 0, 73, 74, 0, 75, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	53, 54, 0, 0, 0, 0, 55, 0, 56, 51,
	52, 64, 65, 66, 67, 68, 69, 70, 71, 0,
	101, 0, 50, 0, 0, 0, 629, 24, 76, 77,
	0, 0, 0, 0, 46, 84, 85, 35, 0, 96,
	0, 26, 0, 0, 0, 102, 25, 17, 16, 0,
	18, 0, 29, 0, 30, 0, 0, 19, 0, 0,
	0, 20, 21, 34, 36, 0, 22, 32, 0, 0,
	33, 0, 0, 23, 0, 28, 0, 58, 290, 38,
	39, 40, 0, 0, 0, 0, 100, 0, 93, 89,
	90, 91, 86, 87, 0, 0, 0, 0, 0, 0,
	94, 0, 0, 0, 0, 125, 92, 88, 104, 0,
	57, 0, 31, 13, 0, 0, 95, 97, 59, 60,
	61, 62, 63, 0, 0, 0, 0, 73, 74, 0,
	75, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 53, 54, 0, 0, 0, 0, 55,
	0, 56, 51, 52, 64, 65, 66, 67, 68, 69,
	70, 71, 0, 101, 0, 50, 0, 0, 0, 0,
	24, 76, 77, 0, 0, 0, 0, 46, 84, 85,
	35, 0, 96, 0, 26, 0, 0, 0, 102, 25,
	17, 16, 0, 18, 0, 29, 0, 30, 0, 0,
	19, 0, 0, 0, 20, 21, 34, 36, 0, 22,
	32, 0, 0, 33, 0, 0, 23, 0, 28, 0,
	58, 290, 38, 39, 40, 0, 0, 0, 0, 100,
	0, 93, 89, 90, 91, 86, 87, 0, 0, 0,
	0, 0, 0, 94, 0, 0, 0, 0, 125, 92,
	88, 104, 0, 57, 0, 31, 13, 521, 0, 95,
	97, 59, 60, 61, 62, 63, 0, 0, 0, 0,
	73, 74, 0, 75, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 53, 54, 0, 0,
	0, 0, 55, 0, 56, 51, 52, 64, 65, 66,
	67, 68, 69, 70, 71, 0, 101, 0, 50, 0,
	0, 0, 0, 24, 76, 77, 0, 0, 0, 0,
	46, 84, 85, 35, 0, 96, 0, 26, 0, 0,
	0, 102, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 0, 22, 32, 0, 0, 33, 0, 0, 23,
	0, 28, 0, 58, 290, 38, 39, 40, 0, 0,
	0, 0, 100, 0, 93, 89, 90, 91, 86, 87,
	0, 0, 0, 0, 0, 0, 94, 0, 0, 0,
	0, 125, 92, 88, 104, 0, 57, 0, 31, 13,
	284, 0, 95, 97, 59, 60, 61, 62, 63, 0,
	0, 0, 0, 73, 74, 0, 75, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 0, 0, 55, 0, 56, 51, 52,
	64, 65, 66, 67, 68, 69, 70, 71, 0, 101,
	0, 50, 0, 0, 0, 0, 24, 76, 77, 0,
	0, 0, 0, 46, 84, 85, 35, 0, 96, 0,
	26, 0, 0, 0, 102, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 36, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 0, 58, 290, 38, 39,
	40, 0, 0, 0, 0, 100, 0, 93, 89, 90,
	91, 86, 87, 0, 0, 0, 0, 0, 0, 94,
	0, 0, 0, 0, 125, 92, 88, 104, 0, 57,
	0, 31, 13, 0, 0, 95, 97, 59, 60, 61,
	62, 63, 0, 0, 0, 0, 73, 74, 0, 75,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 706, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 53, 54, 0, 0, 0, 0, 55, 0,
	56, 51, 52, 64, 65, 66, 67, 68, 69, 70,
	71, 0, 101, 0, 50, 0, 0, 0, 0, 24,
	0, 0, 0, 0, 0, 0, 46, 84, 85, 35,
	0, 96, 0, 26, 0, 0, 0, 102, 25, 17,
	16, 0, 18, 0, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 0, 0, 22, 32,
	0, 0, 33, 0, 0, 23, 0, 28, 0, 58,
	0, 0, 0, 0, 0, 0, 0, 0, 100, 0,
	93, 89, 90, 91, 86, 87, 0, 0, 0, 0,
	0, 0, 94, 0, 0, 0, 0, 125, 92, 88,
	104, 0, 57, 0, 31, 13, 0, 0, 95, 97,
	59, 60, 61, 62, 63, 0, 0, 0, 0, 73,
	74, 0, 75, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 777, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 53, 54, 0, 0, 0,
	0, 55, 0, 56, 51, 52, 64, 65, 66, 67,
	68, 69, 70, 71, 0, 101, 0, 50, 0, 0,
	0, 0, 24, 0, 0, 0, 0, 0, 0, 46,
	84, 85, 35, 0, 96, 0, 26, 0, 0, 0,
	102, 25, 17, 16, 0, 18, 0, 29, 0, 30,
	0, 0, 19, 0, 0, 0, 20, 21, 34, 0,
	0, 22, 32, 0, 0, 33, 0, 0, 23, 0,
	28, 0, 58, 0, 0, 0, 0, 0, 0, 0,
	0, 100, 0, 93, 89, 90, 91, 86, 87, 0,
	0, 0, 0, 0, 0, 94, 0, 0, 0, 0,
	125, 92, 88, 104, 0, 57, 0, 31, 13, 0,
	0, 95, 97, 59, 60, 61, 62, 63, 0, 0,
	0, 0, 73, 74, 0, 75, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	631, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 53, 54,
	0, 0, 0, 0, 55, 0, 56, 51, 52, 64,
	65, 66, 67, 68, 69, 70, 71, 0, 101, 0,
	50, 0, 0, 0, 0, 24, 0, 0, 0, 0,
	0, 0, 46, 84, 85, 35, 0, 96, 0, 26,
	0, 0, 0, 102, 25, 17, 16, 0, 18, 0,
	29, 0, 30, 0, 0, 19, 0, 0, 0, 20,
	21, 34, 0, 0, 22, 32, 0, 0, 33, 0,
	0, 23, 0, 28, 0, 58, 0, 0, 0, 0,
	0, 0, 0, 0, 100, 0, 93, 89, 90, 91,
	86, 87, 0, 0, 0, 0, 0, 0, 94, 0,
	0, 0, 0, 125, 92, 88, 104, 0, 57, 0,
	31, 13, 0, 0, 95, 97, 59, 60, 61, 62,
	63, 0, 0, 0, 0, 73, 74, 0, 75, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 596, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 53, 54, 0, 0, 0, 0, 55, 0, 56,
	51, 52, 64, 65, 66, 67, 68, 69, 70, 71,
	0, 101, 0, 50, 0, 0, 0, 0, 24, 0,
	0, 0, 0, 0, 0, 46, 84, 85, 35, 0,
	96, 0, 26, 0, 0, 0, 102, 25, 17, 16,
	0, 18, 0, 29, 0, 30, 0, 0, 19, 0,
	0, 0, 20, 21, 34, 0, 0, 22, 32, 0,
	0, 33, 0, 0, 23, 0, 28, 0, 58, 0,
	0, 0, 0, 0, 0, 0, 0, 100, 0, 93,
	89, 90, 91, 86, 87, 0, 0, 0, 0, 0,
	0, 94, 0, 0, 0, 0, 125, 92, 88, 104,
	0, 57, 0, 31, 13, 0, 0, 95, 97, 59,
	60, 61, 62, 63, 0, 0, 0, 0, 73, 74,
	0, 75, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 579, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 53, 54, 0, 0, 0, 0,
	55, 0, 56, 51, 52, 64, 65, 66, 67, 68,
	69, 70, 71, 0, 101, 0, 50, 0, 0, 0,
	0, 24, 0, 0, 0, 0, 0, 0, 46, 84,
	85, 35, 0, 96, 0, 26, 0, 0, 0, 102,
	25, 17, 16, 0, 18, 0, 29, 0, 30, 0,
	0, 19, 0, 0, 0, 20, 21, 34, 0, 0,
	22, 32, 0, 0, 33, 0, 0, 23, 0, 28,
	0, 58, 0, 0, 0, 0, 0, 0, 0, 0,
	100, 0, 93, 89, 90, 91, 86, 87, 0, 0,
	0, 0, 0, 0, 94, 0, 0, 0, 0, 125,
	92, 88, 104, 0, 57, 0, 31, 13, 0, 0,
	95, 97, 59, 60, 61, 62, 63, 0, 0, 0,
	0, 73, 74, 0, 75, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 53, 54, 0,
	0, 0, 0, 55, 0, 56, 51, 52, 64, 65,
	66, 67, 68, 69, 70, 71, 0, 101, 0, 50,
	0, 0, 0, 0, 24, 0, 0, 0, 0, 0,
	0, 46, 84, 85, 35, 0, 96, 0, 26, 0,
	0, 0, 102, 25, 17, 16, 0, 18, 0, 29,
	0, 30, 0, 0, 19, 0, 0, 0, 20, 21,
	34, 0, 0, 22, 32, 0, 0, 33, 0, 0,
	23, 0, 28, 0, 58, 0, 0, 0, 0, 0,
	0, 0, 0, 100, 0, 93, 89, 90, 91, 86,
	87, 0, 0, 0, 0, 0, 0, 94, 0, 0,
	0, 0, 125, 92, 88, 104, 0, 57, 0, 31,
	13, 0, 0, 95, 97, 396, 397, 398, 399, 400,
	0, 401, 402, 403, 439, 440, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 404, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 405, 406, 0, 409, 410, 411, 390, 391, 392,
	393, 394, 395, 407, 408, 0, 0, 386, 0, 0,
	0, 0, 0, 0, 0, 0, 412, 413, 414, 415,
	416, 417, 418, 419, 420, 421, 422, 442, 443, 444,
	445, 446, 434, 435, 436, 437, 438, 423, 424, 425,
	426, 427, 428, 429, 430, 431, 432, 433, 0, 454,
	452, 453, 449, 450, 0, 441, 447, 448, 455, 456,
	458, 457, 459, 460, 396, 397, 398, 399, 400, 0,
	401, 402, 403, 439, 440, 451, 462, 461, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 404, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	405, 406, 0, 409, 410, 411, 622, 623, 624, 621,
	620, 619, 407, 408, 0, 0, 807, 0, 0, 0,
	0, 0, 0, 0, 0, 412, 413, 414, 415, 416,
	417, 418, 419, 420, 421, 422, 442, 443, 444, 445,
	446, 434, 435, 436, 437, 438, 423, 424, 425, 426,
	427, 428, 429, 430, 431, 432, 433, 0, 454, 452,
	453, 449, 450, 0, 441, 447, 448, 455, 456, 458,
	457, 459, 460, 0, 0, 0, 0, 0, 59, 60,
	61, 62, 63, 0, 451, 462, 461, 73, 74, 0,
	75, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 260, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 53, 54, 0, 0, 0, 0, 55,
	0, 56, 51, 52, 64, 65, 66, 67, 68, 69,
	70, 71, 0, 101, 0, 50, 0, 145, 147, 146,
	130, 0, 0, 0, 0, 0, 0, 0, 84, 85,
	109, 0, 96, 0, 0, 0, 0, 169, 102, 170,
	143, 144, 148, 150, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 59, 60, 61, 62, 63, 0, 0, 0,
	58, 73, 74, 0, 75, 155, 0, 0, 261, 100,
	0, 93, 89, 90, 91, 86, 87, 0, 0, 0,
	0, 0, 0, 94, 0, 565, 0, 0, 125, 92,
	88, 104, 0, 57, 0, 0, 0, 53, 54, 95,
	97, 0, 0, 55, 0, 56, 51, 52, 64, 65,
	66, 67, 68, 69, 70, 71, 0, 101, 0, 50,
	0, 0, 0, 0, 130, 0, 0, 0, 0, 0,
	0, 0, 84, 85, 109, 0, 96, 0, 0, 0,
	0, 0, 102, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	633, 0, 0, 0, 0, 0, 59, 60, 61, 62,
	63, 0, 0, 0, 58, 73, 74, 0, 75, 0,
	0, 0, 566, 100, 0, 93, 89, 90, 91, 86,
	87, 0, 0, 0, 0, 0, 0, 94, 0, 0,
	0, 0, 125, 92, 88, 104, 0, 57, 0, 0,
	0, 53, 54, 95, 97, 0, 0, 55, 0, 56,
	51, 52, 64, 65, 66, 67, 68, 69, 70, 71,
	0, 101, 0, 50, 0, 145, 147, 146, 130, 0,
	0, 0, 0, 0, 0, 0, 84, 85, 109, 0,
	96, 0, 0, 0, 0, 169, 102, 170, 143, 144,
	148, 150, 149, 162, 163, 160, 161, 164, 165, 166,
	167, 168, 158, 159, 152, 153, 151, 154, 156, 157,
	59, 60, 61, 62, 63, 0, 0, 0, 58, 73,
	74, 0, 75, 155, 0, 0, 0, 100, 0, 93,
	89, 90, 91, 86, 87, 0, 0, 0, 0, 0,
	0, 94, 0, 0, 0, 0, 125, 92, 88, 104,
	482, 57, 478, 0, 0, 53, 54, 95, 97, 0,
	0, 55, 0, 56, 51, 52, 64, 65, 66, 67,
	68, 69, 70, 71, 0, 101, 0, 50, 0, 0,
	0, 0, 130, 0, 0, 0, 0, 0, 0, 0,
	84, 85, 109, 0, 96, 0, 0, 0, 0, 0,
	102, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 632, 0,
	0, 0, 0, 0, 59, 60, 61, 62, 63, 0,
	0, 0, 58, 73, 74, 0, 75, 0, 0, 0,
	0, 100, 0, 93, 89, 90, 91, 86, 87, 0,
	0, 0, 0, 0, 0, 94, 0, 0, 0, 0,
	125, 92, 88, 104, 482, 57, 0, 0, 0, 53,
	54, 95, 97, 0, 0, 55, 0, 56, 51, 52,
	64, 65, 66, 67, 68, 69, 70, 71, 0, 101,
	0, 50, 0, 145, 147, 146, 130, 0, 0, 0,
	0, 0, 0, 0, 84, 85, 109, 474, 96, 0,
	0, 0, 0, 169, 102, 170, 143, 144, 148, 150,
	149, 162, 163, 160, 161, 164, 165, 166, 167, 168,
	158, 159, 152, 153, 151, 154, 156, 157, 59, 60,
	61, 62, 63, 0, 0, 0, 58, 73, 74, 0,
	75, 155, 0, 0, 0, 100, 0, 93, 89, 90,
	91, 86, 87, 0, 0, 0, 0, 0, 0, 94,
	0, 357, 0, 0, 125, 92, 88, 104, 0, 57,
	0, 0, 0, 53, 54, 95, 97, 0, 0, 55,
	0, 56, 51, 52, 64, 65, 66, 67, 68, 69,
	70, 71, 0, 101, 0, 50, 0, 0, 0, 0,
	130, 0, 0, 0, 0, 0, 0, 0, 84, 85,
	109, 0, 96, 0, 0, 0, 0, 0, 102, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 558, 0, 0, 0,
	0, 0, 59, 60, 61, 62, 63, 0, 0, 0,
	58, 73, 74, 0, 75, 0, 0, 0, 0, 100,
	0, 93, 89, 90, 91, 86, 87, 0, 0, 334,
	0, 0, 0, 94, 0, 0, 0, 0, 125, 92,
	88, 104, 0, 57, 0, 0, 0, 53, 54, 95,
	97, 0, 0, 55, 0, 56, 51, 52, 64, 65,
	66, 67, 68, 69, 70, 71, 0, 101, 0, 50,
	0, 145, 147, 146, 130, 0, 0, 0, 0, 0,
	0, 0, 84, 85, 109, 0, 96, 0, 0, 0,
	0, 169, 102, 170, 143, 144, 148, 150, 149, 162,
	163, 160, 161, 164, 165, 166, 167, 168, 158, 159,
	152, 153, 151, 154, 156, 157, 59, 60, 61, 62,
	63, 0, 0, 0, 58, 73, 74, 0, 75, 155,
	0, 0, 0, 100, 0, 93, 89, 90, 91, 86,
	87, 0, 0, 0, 0, 0, 0, 94, 0, 0,
	0, 0, 125, 92, 88, 104, 0, 57, 0, 0,
	0, 53, 54, 95, 97, 0, 0, 55, 0, 56,
	51, 52, 64, 65, 66, 67, 68, 69, 70, 71,
	0, 101, 0, 50, 0, 0, 0, 0, 130, 0,
	0, 0, 0, 0, 0, 0, 84, 85, 109, 0,
	96, 0, 0, 0, 0, 0, 102, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 554, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 58, 0,
	0, 0, 0, 0, 0, 0, 0, 100, 0, 93,
	89, 90, 91, 86, 87, 0, 0, 0, 0, 0,
	0, 94, 145, 147, 146, 0, 125, 92, 88, 104,
	0, 57, 0, 0, 0, 0, 0, 95, 97, 0,
	0, 0, 169, 0, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 145, 147, 146,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	155, 0, 0, 0, 0, 0, 0, 169, 0, 170,
	143, 144, 148, 150, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 145, 147, 146, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 155, 0, 0, 0, 0,
	0, 0, 169, 0, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 145, 147, 146,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	155, 0, 0, 0, 0, 537, 0, 169, 0, 170,
	143, 144, 148, 150, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 145, 147, 146, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 155, 0, 0, 342, 0,
	0, 0, 169, 0, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 145, 147, 146,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	155, 0, 0, 142, 0, 0, 0, 169, 0, 170,
	143, 144, 148, 150, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 145, 147, 146, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 155, 0, 651, 0, 0,
	0, 0, 169, 0, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 145, 147, 146,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	155, 0, 628, 0, 0, 0, 0, 169, 0, 170,
	143, 144, 148, 150, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 145, 147, 146, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 155, 0, 627, 0, 0,
	0, 0, 169, 0, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 145, 147, 146,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	155, 0, 542, 0, 0, 0, 0, 169, 0, 170,
	143, 144, 148, 150, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 145, 147, 146, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 155, 0, 541, 0, 0,
	0, 0, 169, 0, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 145, 147, 146,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	155, 0, 540, 0, 0, 0, 0, 169, 0, 170,
	143, 144, 148, 150, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 145, 147, 146, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 155, 0, 535, 0, 0,
	0, 0, 169, 0, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 145, 147, 146,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	155, 0, 510, 0, 0, 0, 0, 169, 0, 170,
	143, 144, 148, 150, 149, 162, 163, 160, 161, 164,
	165, 166, 167, 168, 158, 159, 152, 153, 151, 154,
	156, 157, 145, 147, 146, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 155, 0, 506, 0, 0,
	0, 0, 169, 515, 170, 143, 144, 148, 150, 149,
	162, 163, 160, 161, 164, 165, 166, 167, 168, 158,
	159, 152, 153, 151, 154, 156, 157, 0, 145, 147,
	146, 0, 519, 486, 0, 0, 0, 0, 0, 0,
	155, 0, 378, 0, 0, 0, 0, 0, 169, 0,
	170, 143, 144, 148, 150, 149, 162, 163, 160, 161,
	164, 165, 166, 167, 168, 158, 159, 152, 153, 151,
	154, 156, 157, 145, 147, 146, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 155, 0, 0, 0,
	0, 0, 0, 169, 0, 170, 143, 144, 148, 150,
	149, 162, 163, 160, 161, 164, 165, 166, 167, 168,
	158, 159, 152, 153, 151, 154, 156, 157, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 155,
}
var yyPact = [...]int{

	-1000, -1000, 1284, -1000, -1000, -1000, -1000, -1000, -1000, 284,
	101, 334, 462, -1000, -1000, -1000, 283, 4508, 282, 281,
	5752, 5752, 5752, 9, 426, 5752, -1000, 5982, 279, 277,
	275, -1000, -24, 5752, 507, 598, 574, 407, 504, 502,
	499, 533, 563, 2421, -1000, -1000, 271, -1000, -1000, 146,
	5752, 345, 345, 5752, 5752, 5752, 5752, 5752, 266, 5752,
	5752, 265, 5752, 5752, 5752, 5752, 5752, 5752, 5752, 5752,
	5752, 5752, -1000, 5752, 5752, 5752, -1000, -1000, -1000, 528,
	-1000, 308, 219, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 432, 388, -1000, 48, 206, 206,
	264, 4954, -1000, 293, 433, 186, 433, -54, -1000, -1000,
	162, 380, 261, 355, 433, -1000, -1000, -1000, -1000, 257,
	-1000, 634, 3367, 5752, 382, 288, 5752, 5752, 159, 6613,
	-1000, 152, 149, 256, -1000, -1000, 255, -1000, 622, 214,
	-1000, 6613, -1000, 5752, 5752, 5752, 5752, 5752, 5752, 5752,
	5752, 5752, 5752, 5752, 5752, 5752, 5752, 5752, 5752, 5752,
	5752, 5752, 5752, 5752, 5752, 5752, 5752, 5752, 5752, 5638,
	5752, 345, 5752, 462, -1000, 5937, 148, -1000, 494, -1000,
	492, -1000, 332, -27, 337, 260, 4508, 228, 145, 595,
	5524, 5752, 5752, 5752, 5752, 5752, 5752, 5752, 5752, 5752,
	5752, 5752, 5752, -1000, -1000, 5752, 5752, 5752, 12, -1000,
	-1000, 528, 5752, -1000, -1000, 534, 534, 534, 534, 6432,
	5752, 6613, 6613, 5752, 6613, 6613, 534, 534, 534, 534,
	534, 534, 534, 534, 1269, 1432, 1269, 5752, 814, 814,
	404, -1000, 425, -1000, 396, 5410, 345, 84, 394, 5752,
	-1000, -1000, 5182, -1000, 4954, -63, 667, -1000, -1000, 6568,
	345, 222, 474, 293, 143, 293, -1000, -1000, 1121, -1000,
	142, 213, 346, 433, -1000, 366, 140, 463, 339, -1000,
	-1000, 462, 5752, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	212, 6387, 208, 136, 664, 6613, 6342, -1000, -1000, -1000,
	-1000, 9, -1000, 426, 5752, -1000, 5752, 1756, 946, 2559,
	1269, 1106, 1919, 2227, 2077, 596, 596, 596, 534, 534,
	534, 534, 2097, 2097, 811, 811, 811, 811, 811, 2085,
	2085, 2085, 2085, 6522, 5752, 1595, 660, -1000, -1000, 6477,
	253, 3204, -1000, -1000, 207, 332, 330, 278, -1000, -33,
	278, 5752, -1000, 5752, -1000, -1000, 1269, 5752, 1269, 1269,
	1269, 1269, 1269, 1269, 1269, 1269, 1269, 1269, 1269, 1269,
	6297, -65, 5892, 206, -1000, 5752, -1000, 6252, -1000, 6207,
	6162, 5752, -69, -1000, 206, -1000, -1000, -1000, 5752, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 206, -1000, -1000, -1000, -1000, -1000,
	-1000, 529, 441, 5701, 27, -45, -1000, 5473, -1000, 659,
	-1000, 6613, 5752, 185, -1000, 4954, 5068, -1000, 4954, -1000,
	-1000, 958, -1000, -1000, -1000, 126, 310, -1000, 433, 280,
	392, -1000, 123, -1000, 6613, 184, 4345, 5752, 5752, 5752,
	86, -1000, -1000, 6613, -1000, 5752, 1595, 181, 345, 183,
	4182, -1000, 226, 330, -36, 278, -1000, 493, -1000, 643,
	-1000, 6117, 6072, 3041, 2227, 4019, -1000, -1000, -1000, 5245,
	-1000, -1000, -1000, 1269, -1000, -1000, 5017, -1000, -70, -1000,
	-1000, 399, -1000, -1000, -1000, -1000, 5752, -1000, -1000, 179,
	5296, 6613, -1000, -1000, 6613, 345, 204, 178, -1000, 433,
	57, 656, -1000, -1000, 433, 392, 132, -1000, -1000, -1000,
	6027, 131, 6613, -1000, 128, 121, 1595, 120, -1000, 269,
	-1000, 345, 201, 4954, -1000, -1000, -1000, 353, 171, 658,
	-1000, 575, -1000, -1000, 292, -1000, -1000, -1000, -37, -1000,
	643, -1000, -1000, 389, 359, 278, 566, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, 378, 278, 4508, 592, 117,
	-1000, -1000, -1000, -1000, -1000, -1000, 358, -1000, -1000, -1000,
	4954, -1000, 645, -1000, 433, -47, 392, -1000, 656, -1000,
	2878, 99, 5752, 109, -1000, 459, -1000, -1000, 3693, 183,
	-1000, 4954, -83, 2715, -1000, 192, -42, 588, 226, 215,
	-1000, -1000, -1000, 153, 114, -1000, 617, 4671, 574, 78,
	-1000, -1000, -1000, -1000, -1000, -1000, 3530, -48, 169, -49,
	433, 645, -1000, -1000, -50, 96, -1000, 164, -1000, 5752,
	90, 25, 93, 386, -1000, -1000, -1000, 154, 127, -1000,
	83, 278, -1000, -43, 226, -1000, 419, -1000, 105, -1000,
	-1000, 389, 5752, 113, -1000, 613, 4671, -1000, -1000, 2570,
	3530, -1000, -1000, -1000, -1000, -51, -1000, -1000, 3856, 799,
	-1000, -1000, -1000, -1000, -1000, 82, 2407, 3693, -1000, -1000,
	455, -1000, 2244, -1000, -1000, 610, -1000, -1000, 6613, -1000,
	4671, 5752, 188, -1000, 2099, -1000, 76, 66, 348, 369,
	190, -1000, 288, -1000, -1000, -1000, -1000, -1000, -1000, 3530,
	-1000, 43, -1000, 87, 278, -1000, 1936, 5752, -1000, 6613,
	226, -1000, -1000, -1000, -1000, 278, 4810, 4671, 1773, 3530,
	-1000, -53, -1000, -1000, 6613, 85, 643, -1000, -1000, 4671,
	-1000, -22, -1000, 588, -1000, -1000, 1610, -57, -1000, -1000,
	-1000, -1000, 1447, -1000,
}
var yyPgo = [...]int{

	0, 620, 766, 765, 15, 8, 764, 2, 763, 25,
	5, 80, 29, 761, 1, 760, 59, 50, 758, 3,
	13, 35, 4, 757, 20, 0, 756, 754, 89, 82,
	753, 751, 750, 748, 747, 24, 746, 745, 744, 28,
	88, 743, 77, 741, 73, 740, 48, 739, 44, 19,
	41, 78, 738, 737, 11, 93, 52, 734, 733, 731,
	730, 18, 727, 726, 725, 7, 724, 14, 722, 10,
	721, 6, 719, 718, 9, 715, 713, 712, 711, 710,
	706, 500, 84, 705, 39, 704, 702, 701, 33, 698,
	697, 659, 696, 695, 27, 30, 475, 31, 16, 83,
	46, 42, 692, 40, 38, 79, 690, 43, 687, 684,
	90, 680, 17, 12,
}
var yyR1 = [...]int{

	0, 111, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 6,
	6, 6, 6, 6, 6, 6, 7, 7, 9, 9,
	10, 10, 10, 11, 11, 8, 8, 8, 8, 8,
	8, 8, 8, 8, 8, 8, 8, 8, 8, 91,
	91, 92, 92, 93, 93, 94, 94, 95, 95, 96,
	96, 97, 97, 98, 98, 99, 99, 14, 14, 13,
	13, 13, 13, 13, 13, 12, 12, 12, 12, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 58,
	58, 59, 59, 60, 60, 55, 55, 56, 57, 57,
	30, 30, 31, 31, 32, 32, 33, 33, 34, 34,
	35, 35, 36, 36, 38, 38, 38, 38, 39, 39,
	39, 113, 113, 37, 37, 49, 49, 49, 49, 50,
	51, 51, 52, 52, 53, 53, 53, 53, 53, 53,
	54, 54, 41, 41, 42, 43, 43, 44, 44, 45,
	45, 46, 47, 47, 48, 112, 112, 16, 16, 15,
	15, 1, 1, 100, 101, 103, 103, 102, 102, 104,
	104, 61, 61, 62, 62, 62, 62, 71, 71, 72,
	72, 72, 73, 73, 74, 74, 75, 76, 76, 76,
	76, 77, 77, 78, 79, 79, 63, 63, 68, 68,
	69, 70, 70, 64, 64, 65, 65, 65, 65, 65,
	65, 66, 66, 67, 67, 17, 22, 22, 23, 23,
	24, 24, 18, 18, 4, 4, 2, 2, 3, 3,
	20, 20, 21, 21, 21, 19, 19, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 81, 81, 81, 81,
	82, 82, 82, 82, 82, 82, 82, 83, 83, 83,
	83, 84, 84, 84, 85, 85, 86, 87, 87, 87,
	108, 108, 108, 88, 88, 88, 25, 25, 40, 40,
	27, 27, 27, 27, 27, 27, 109, 109, 109, 109,
	110, 110, 110, 105, 105, 106, 106, 107, 107, 28,
	28, 28, 90, 90, 90, 29, 29, 29, 89, 89,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 3,
	1, 2, 3, 2, 0, 1, 1, 1, 1, 1,
	4, 3, 5, 4, 3, 4, 3, 4, 3, 1,
	1, 6, 7, 6, 7, 3, 1, 3, 1, 3,
	1, 1, 2, 1, 3, 1, 2, 2, 0, 1,
	1, 1, 1, 1, 4, 3, 1, 1, 5, 7,
	9, 5, 3, 3, 3, 3, 3, 3, 1, 2,
	6, 7, 9, 5, 1, 6, 3, 3, 2, 0,
	9, 1, 3, 0, 4, 3, 1, 3, 1, 4,
	5, 6, 1, 3, 6, 7, 3, 6, 1, 4,
	0, 1, 3, 1, 3, 4, 4, 5, 0, 5,
	4, 1, 1, 1, 4, 1, 2, 4, 3, 1,
	0, 1, 3, 1, 3, 1, 4, 2, 6, 4,
	1, 4, 3, 1, 1, 3, 1, 1, 3, 3,
	1, 1, 1, 3, 1, 0, 1, 8, 7, 1,
	2, 1, 1, 5, 6, 0, 2, 0, 2, 0,
	2, 2, 0, 3, 4, 3, 9, 1, 3, 1,
	2, 3, 1, 2, 2, 2, 3, 3, 3, 4,
	3, 1, 1, 3, 1, 3, 1, 1, 3, 1,
	3, 0, 1, 1, 2, 1, 1, 1, 1, 1,
	1, 3, 1, 1, 3, 10, 1, 0, 1, 3,
	4, 6, 0, 1, 0, 1, 0, 1, 0, 1,
	1, 2, 1, 1, 1, 0, 2, 3, 4, 2,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 2, 2, 2, 2, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 2, 2, 2, 2, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 5, 4, 3,
	4, 2, 2, 4, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 1, 2, 1, 2, 4, 2,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	3, 2, 3, 3, 1, 1, 2, 2, 1, 2,
	1, 4, 3, 3, 3, 6, 3, 1, 1, 2,
	1, 1, 3, 3, 1, 1, 1, 1, 3, 1,
	1, 3, 1, 4, 3, 1, 1, 1, 0, 1,
	1, 4, 4, 4, 4, 1, 2, 4, 4, 2,
	1, 3, 1, 2, 4, 1, 3, 1, 2, 1,
	1, 3, 1, 3, 1, 1, 4, 2, 3, 3,
}
var yyChk = [...]int{

	-1000, -111, -11, -8, -12, -17, -16, -100, -101, 127,
	154, 120, 114, 162, -31, -33, 97, 96, 99, 106,
	110, 111, 115, 122, 76, 95, 90, -25, 124, 101,
	103, 161, 116, 119, 112, 86, 113, -15, 128, 129,
	130, -30, -32, -28, -26, -1, 83, -27, -89, -87,
	71, 58, 59, 49, 50, 55, 57, 159, 126, 4,
	5, 6, 7, 8, 60, 61, 62, 63, 64, 65,
	66, 67, -80, 13, 14, 16, 77, 78, -29, -84,
	-109, -85, -86, -88, 84, 85, 141, 142, 156, 138,
	139, 140, 155, 137, 149, 165, 88, 166, -10, -108,
	135, 69, 94, -9, 157, 159, 157, -9, 162, 86,
	-93, -91, -96, -9, 157, 113, 114, -99, -98, -55,
	-56, 86, -14, 159, -12, 154, 159, 159, -40, -25,
	76, -40, -40, -41, -42, -29, -43, -44, 88, -45,
	-46, -25, 161, 33, 34, 10, 12, 11, 35, 37,
	36, 51, 49, 50, 52, 68, 53, 54, 47, 48,
	40, 41, 38, 39, 42, 43, 44, 45, 46, 30,
	32, 159, 159, 159, 162, -25, 86, 31, -4, 37,
	128, -1, 86, 86, 86, 73, 74, 73, 75, 74,
	17, 18, 19, 20, 29, 21, 22, 23, 24, 25,
	26, 27, 28, 58, 59, 159, 69, 162, 133, -25,
	-28, -84, 159, -88, -28, -25, -25, -25, -25, -25,
	159, -25, -25, 159, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, 69, 153, 153,
	93, 150, -81, -82, 88, 151, 152, -81, 93, 162,
	-29, -105, 159, -105, 159, -50, -52, -51, -53, -25,
	37, 134, 157, -9, 160, -9, 161, 162, -11, 161,
	-92, -96, -9, 157, 161, 9, 157, 105, -9, -98,
	161, 9, 17, -13, 163, -12, -17, -16, -100, -101,
	127, -25, 97, -35, -36, -25, -25, 161, 161, 161,
	161, 9, 161, 9, 17, 161, 9, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, 31, -25, -47, -48, -28, -25,
	-55, -14, 161, 161, 86, 86, -103, 131, 162, -102,
	131, 159, -12, 159, 161, 31, -25, 37, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -40, -25, -90, 86, 162, -29, -25, 160, -25,
	-25, 15, -40, -7, -110, -29, 86, -6, 162, -5,
	76, 77, 78, 79, 80, 81, 4, 5, 6, 7,
	8, 10, 11, 12, 56, 70, 71, 82, 83, 73,
	74, 75, 95, 96, 97, 98, 99, 100, 101, 102,
	103, 104, 105, 116, 117, 118, 119, 120, 121, 122,
	123, 124, 125, 126, 111, 112, 113, 114, 115, 13,
	14, 134, 106, 107, 108, 109, 110, 135, 136, 131,
	132, 154, 129, 130, 128, 137, 138, 140, 139, 141,
	142, 156, 155, -7, -110, -29, 150, -82, 150, -82,
	93, 69, 133, -25, 87, -28, 165, -25, 160, -106,
	-107, -25, 158, -50, 164, 9, 15, -28, 159, 86,
	161, -11, 163, 161, 161, 157, -9, -99, 157, -9,
	162, 86, 157, -56, -25, 159, 160, 159, 161, 9,
	160, -42, -44, -25, -46, 31, -25, -112, 9, 105,
	160, 163, 159, -103, -104, 132, -10, -61, 162, -71,
	-10, -25, -25, -14, -25, 160, 164, 163, -105, -25,
	160, 160, 160, -25, 164, -105, -25, -105, -83, 86,
	89, 50, 88, 86, 163, 163, 69, 163, 163, -112,
	9, -25, 160, -51, -25, 37, 134, -50, 163, 162,
	157, -94, -97, -98, -91, 162, 160, -34, -12, 31,
	-25, -35, -25, -38, 162, 31, -25, 160, -48, -49,
	-28, 37, 134, 69, -57, -12, 31, -58, -22, -23,
	-24, -18, -20, -21, 30, -10, 135, 136, -104, 162,
	-71, 163, -62, -63, -70, 120, -64, 123, -65, 81,
	80, 79, 76, 77, 78, -61, 9, 160, 160, 75,
	-12, 31, 163, 163, 164, 89, -25, 160, -107, -28,
	159, 160, -95, -98, 162, -112, 9, -98, -94, 161,
	-14, 160, 161, -39, 161, -39, 161, 161, 160, 15,
	-28, 159, -50, -14, -60, 117, 118, 160, 9, -2,
	37, -21, 162, -61, -66, -67, 88, 114, 113, -71,
	-65, 163, -10, -12, 31, 161, -14, 164, -50, -112,
	9, -95, 163, -97, -112, 98, 161, -35, 163, 108,
	109, -39, 107, -39, -54, -12, 31, -49, -50, 164,
	104, 159, 162, -19, 31, -24, -3, 158, -61, 163,
	161, 9, 17, -68, -69, -7, -4, -72, 161, 162,
	-14, 163, 160, 163, -98, -112, 163, 161, 160, -25,
	-113, 31, 161, 163, 161, 107, -14, 160, 160, 161,
	-59, -10, -14, 162, -20, 88, 163, -67, -25, 161,
	9, 17, -7, 163, -73, -74, -75, -76, -78, -77,
	-10, -7, 154, 86, 163, -37, -12, 31, -113, -14,
	161, 102, -54, 88, 35, 163, -14, 17, -69, -25,
	159, 163, -74, 161, 161, 121, 105, 153, -14, -14,
	161, 160, -10, 163, -25, -22, -71, 86, -5, -65,
	-7, 100, 162, 160, -7, 161, -14, -19, 163, -79,
	161, 162, -14, 163,
}
var yyDef = [...]int{

	84, -2, 1, 83, 85, 86, 87, 88, 89, 0,
	0, 0, 0, 118, 126, 127, 0, 0, 0, 0,
	418, 418, 418, 0, 404, 0, 138, 0, 0, 0,
	0, 144, 0, 0, 0, 78, 284, 0, 0, 0,
	0, 162, 0, -2, 417, 219, 0, -2, 440, 406,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 364, 0, 366, 0, 221, 222, 420, 385,
	425, 0, 0, -2, 370, 371, 372, 373, 374, 375,
	376, 377, 378, 379, 0, 0, 445, 0, -2, 0,
	0, 190, 415, 80, 0, 0, 0, 0, 84, 78,
	0, 0, 0, 113, 0, 99, 100, 110, 115, 0,
	156, 0, 0, 0, 0, 0, 170, 0, 0, 419,
	404, 0, 0, 0, 203, 204, 0, 206, 207, 0,
	210, 211, 139, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 118, 0, 0, 148, 0, 285,
	0, 220, 225, 0, 227, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 312, 314, 0, 418, 0, 0, 299,
	-2, 0, 0, -2, -2, 333, 334, 335, 336, 0,
	0, 351, 352, 0, 354, 355, 356, 357, 358, 359,
	360, 361, 362, 363, 365, 367, 369, 418, 0, 0,
	0, 381, 0, 388, 390, 0, 0, 0, 0, 0,
	447, 426, 0, 429, 190, 0, 189, 193, 191, 195,
	0, 0, 0, 81, 0, 82, 91, 84, 0, 94,
	0, 0, 113, 0, 96, 0, 0, 0, 113, 116,
	98, 0, 0, 117, 125, 119, 120, 121, 122, 123,
	0, 0, 0, 0, 171, 173, 0, 132, 133, 134,
	135, 0, 136, 0, 0, 137, 0, 316, 317, 318,
	319, 320, 321, 322, 323, 324, 325, 326, 327, 328,
	329, 330, 331, 332, -2, -2, -2, -2, -2, -2,
	-2, -2, -2, 0, 0, 349, 215, 212, -2, 0,
	0, 0, 146, 147, 0, 225, 229, 0, 232, 0,
	0, 0, 163, 0, 166, 118, 297, 0, 300, 301,
	302, 303, 304, 305, 306, 307, 308, 309, 310, 311,
	0, 0, 0, 441, 442, 0, 444, 0, -2, 0,
	0, 0, 0, -2, 0, -2, 76, 77, 0, 69,
	70, 71, 72, 73, 74, 75, 2, 3, 4, 5,
	6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
	16, 17, 18, 19, 20, 21, 22, 23, 24, 25,
	26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
	36, 37, 38, 39, 40, 41, 42, 43, 44, 45,
	46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
	56, 57, 58, 59, 60, 61, 62, 63, 64, 65,
	66, 67, 68, -2, 0, -2, 380, 389, 383, 386,
	387, 0, 0, 0, 0, 407, 382, 0, 433, 215,
	435, 437, 0, 0, 414, 190, 0, -2, 190, 79,
	90, 0, 93, 95, 97, 0, 113, 109, 0, 113,
	0, 114, 0, 155, 157, 0, 0, 0, 170, 0,
	0, 202, 205, 208, 209, 0, 348, 0, 216, 0,
	0, 149, -2, 229, 0, 0, 226, 261, 232, 228,
	237, 0, 0, 0, 298, 0, 421, 423, 424, 0,
	-2, 350, 353, 368, 422, 427, 0, 428, 0, 397,
	398, 0, 400, 392, 393, 394, 0, 396, 446, 0,
	216, 438, 413, 192, 194, 0, 0, 0, 92, 0,
	0, 215, 106, 111, 0, 0, 0, 128, 168, 118,
	0, 0, 172, 131, 178, 178, 347, 0, 213, 0,
	-2, 0, 0, 190, 143, 158, 118, 153, 0, 276,
	278, 286, 283, 290, 0, 292, 293, 294, 0, 232,
	230, 223, 231, 0, 0, 0, -2, 257, 263, 265,
	266, 267, 268, 269, 270, 261, 0, 0, 0, 0,
	160, 118, 443, 431, 391, 399, 0, 434, 436, -2,
	190, 199, 215, 108, 0, 0, 216, 112, 215, 124,
	0, 0, 170, 0, 178, 0, 178, 140, 0, 0,
	-2, 190, 0, 0, 145, 0, 0, 295, 282, 288,
	287, 291, 232, 261, 0, 272, 273, 0, 284, 0,
	264, 224, 238, 161, 118, 167, 164, 0, 0, 0,
	216, 215, 103, 105, 0, 0, 129, 0, 174, 0,
	0, 0, 0, 0, 141, 200, 118, 0, 0, -2,
	0, 0, 118, 0, 0, 279, 0, 289, 261, 218,
	233, 0, 0, 0, 259, 0, 0, 235, 239, 0,
	165, 395, 198, 101, 107, 0, 104, 169, 0, 0,
	118, 181, 182, 175, 176, 0, 0, 0, 187, 159,
	0, 151, 0, 118, 296, 280, 217, 271, 274, 234,
	0, 0, 0, 240, 0, 242, 0, 0, 252, 0,
	0, 251, 57, -2, 102, 130, 183, 118, 118, 180,
	177, 0, 142, 0, 0, 154, 0, 0, 258, 260,
	-2, 241, 243, 244, 245, 0, 0, 0, 0, 179,
	201, 0, 152, 275, 281, 0, 246, 247, 248, 250,
	253, 0, 118, 295, 249, 184, 0, 0, 150, 236,
	254, 118, 0, 255,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 165, 3, 166, 54, 37, 3,
	159, 160, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 161,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 162, 35, 163, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			fmt.Println(yyDollar[1].node)
		}
	case 2:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 3:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 5:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 10:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 11:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 12:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 13:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 14:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 15:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 16:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 17:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 18:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 21:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 22:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 23:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 24:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 27:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 28:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 29:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 30:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:315
		{
			yyVAL.value = yyDollar[1].token
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 33:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 34:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 35:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 36:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 37:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 38:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 39:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:316
		{
			yyVAL.value = yyDollar[1].token
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 44:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 46:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 47:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 48:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 49:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 50:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 51:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 52:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.value = yyDollar[1].token
		}
	case 53:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.value = yyDollar[1].token
		}
	case 54:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.value = yyDollar[1].token
		}
	case 55:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.value = yyDollar[1].token
		}
	case 56:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.value = yyDollar[1].token
		}
	case 57:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.value = yyDollar[1].token
		}
	case 58:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.value = yyDollar[1].token
		}
	case 59:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.value = yyDollar[1].token
		}
	case 60:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.value = yyDollar[1].token
		}
	case 61:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.value = yyDollar[1].token
		}
	case 62:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.value = yyDollar[1].token
		}
	case 63:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.value = yyDollar[1].token
		}
	case 64:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.value = yyDollar[1].token
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.value = yyDollar[1].token
		}
	case 66:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.value = yyDollar[1].token
		}
	case 67:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.value = yyDollar[1].token
		}
	case 68:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.value = yyDollar[1].token
		}
	case 69:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].value
		}
	case 70:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 72:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 73:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 74:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 75:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].token)
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:329
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].value)
		}
	case 78:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:333
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 79:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:334
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:338
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 81:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:339
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 82:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:340
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 83:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:344
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 84:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:345
		{
			yyVAL.node = Node("Statements")
		}
	case 85:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:349
		{
			yyVAL.node = yyDollar[1].node
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:350
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:351
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:352
		{
			yyVAL.node = yyDollar[1].node
		}
	case 89:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:353
		{
			yyVAL.node = yyDollar[1].node
		}
	case 90:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:354
		{
			yyVAL.node = Node("THaltCompiler")
		}
	case 91:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:355
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 92:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:357
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 93:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:358
		{
			yyVAL.node = Node("Namespace").append(yyDollar[3].node)
		}
	case 94:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:359
		{
			yyVAL.node = yyDollar[2].node
		}
	case 95:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:360
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:361
		{
			yyVAL.node = yyDollar[2].node
		}
	case 97:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:362
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 98:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:363
		{
			yyVAL.node = yyDollar[2].node
		}
	case 99:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:367
		{
			yyVAL.node = Node("FuncUseType")
		}
	case 100:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:368
		{
			yyVAL.node = Node("ConstUseType")
		}
	case 101:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:373
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 102:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:375
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 103:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:380
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 104:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:382
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 105:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:387
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 106:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:388
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:392
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 108:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:393
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 109:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:396
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 110:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:397
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 111:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:400
		{
			yyVAL.node = yyDollar[1].node
		}
	case 112:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:401
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 113:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:404
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node)
		}
	case 114:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:405
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node).append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 115:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:408
		{
			yyVAL.node = yyDollar[1].node
		}
	case 116:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:409
		{
			yyVAL.node = yyDollar[2].node
		}
	case 117:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:413
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 118:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:414
		{
			yyVAL.node = Node("stmt")
		}
	case 119:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:418
		{
			yyVAL.node = yyDollar[1].node
		}
	case 120:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:419
		{
			yyVAL.node = yyDollar[1].node
		}
	case 121:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:420
		{
			yyVAL.node = yyDollar[1].node
		}
	case 122:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:421
		{
			yyVAL.node = yyDollar[1].node
		}
	case 123:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:422
		{
			yyVAL.node = yyDollar[1].node
		}
	case 124:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:423
		{
			yyVAL.node = Node("THaltCompiler")
		}
	case 125:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:426
		{
			yyVAL.node = yyDollar[2].node
		}
	case 126:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:427
		{
			yyVAL.node = yyDollar[1].node
		}
	case 127:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:428
		{
			yyVAL.node = yyDollar[1].node
		}
	case 128:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:430
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 129:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:436
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 130:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:442
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 131:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:449
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 132:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:450
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 133:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:451
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 134:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:452
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 135:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:453
		{
			yyVAL.node = yyDollar[2].node
		}
	case 136:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:454
		{
			yyVAL.node = yyDollar[2].node
		}
	case 137:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:455
		{
			yyVAL.node = yyDollar[2].node
		}
	case 138:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:456
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 139:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:457
		{
			yyVAL.node = yyDollar[1].node
		}
	case 140:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:459
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 141:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:461
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 142:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:468
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 143:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:475
		{
			yyVAL.node = Node("Declare").append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 144:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:476
		{
			yyVAL.node = Node("")
		}
	case 145:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:478
		{
			yyVAL.node = Node("Try").
				append(yyDollar[3].node).
				append(yyDollar[5].node).
				append(yyDollar[6].node)
		}
	case 146:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:484
		{
			yyVAL.node = Node("Throw").append(yyDollar[2].node)
		}
	case 147:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:485
		{
			yyVAL.node = Node("GoTo").attribute("Label", yyDollar[2].token)
		}
	case 148:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:486
		{
			yyVAL.node = Node("Label").attribute("name", yyDollar[1].token)
		}
	case 149:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:489
		{
			yyVAL.node = Node("CatchList")
		}
	case 150:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:491
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[4].node).append(Node("Variable").attribute("name", yyDollar[5].token)).append(yyDollar[8].node)
		}
	case 151:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:494
		{
			yyVAL.node = Node("CatchNameList").append(yyDollar[1].node)
		}
	case 152:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:495
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 153:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:499
		{
			yyVAL.node = Node("")
		}
	case 154:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:500
		{
			yyVAL.node = Node("Finnaly").append(yyDollar[3].node)
		}
	case 155:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:504
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 156:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:505
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 157:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:509
		{
			yyVAL.node = Node("Const").attribute("name", yyDollar[1].token).append(yyDollar[3].node)
		}
	case 158:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:513
		{
			yyVAL.node = yyDollar[1].node
		}
	case 159:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:514
		{
			yyVAL.node = yyDollar[2].node
		}
	case 160:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:519
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 161:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:523
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 162:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:529
		{
			yyVAL.node = yyDollar[1].node
		}
	case 163:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:531
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 164:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:538
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 165:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:542
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 166:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:548
		{
			yyVAL.node = yyDollar[1].node
		}
	case 167:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:550
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 168:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:556
		{
			yyVAL.node = yyDollar[1].node
		}
	case 169:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:557
		{
			yyVAL.node = yyDollar[2].node
		}
	case 170:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:561
		{
			yyVAL.node = Node("")
		}
	case 171:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:562
		{
			yyVAL.node = yyDollar[1].node
		}
	case 172:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:565
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 173:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:566
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 174:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:570
		{
			yyVAL.node = yyDollar[2].node
		}
	case 175:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:571
		{
			yyVAL.node = yyDollar[3].node
		}
	case 176:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:572
		{
			yyVAL.node = yyDollar[2].node
		}
	case 177:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:573
		{
			yyVAL.node = yyDollar[3].node
		}
	case 178:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:577
		{
			yyVAL.node = Node("CaseList")
		}
	case 179:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:579
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 180:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:583
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 183:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:594
		{
			yyVAL.node = yyDollar[1].node
		}
	case 184:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:595
		{
			yyVAL.node = yyDollar[2].node
		}
	case 185:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:599
		{
			yyVAL.node = yyDollar[1].node
		}
	case 186:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:600
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 187:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:601
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 188:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:602
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:606
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 190:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:610
		{
			yyVAL.node = Node("")
		}
	case 191:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:611
		{
			yyVAL.node = yyDollar[1].node
		}
	case 192:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:616
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 193:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:617
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 194:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:621
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 195:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:622
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 196:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:623
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 197:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:624
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 198:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:626
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 199:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:632
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 200:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:639
		{
			yyVAL.node = yyDollar[1].node
		}
	case 201:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:640
		{
			yyVAL.node = yyDollar[2].node
		}
	case 202:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:644
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 203:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:645
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 204:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:649
		{
			yyVAL.node = yyDollar[1].node
		}
	case 205:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:653
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 206:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:654
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 207:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:658
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 208:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:659
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 209:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:663
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 210:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:664
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 211:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:668
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:672
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:673
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 214:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:677
		{
			yyVAL.node = yyDollar[1].node
		}
	case 217:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line parser.y:687
		{
			yyVAL.node = Node("Class").
				attribute("name", yyDollar[3].token).
				append(yyDollar[1].node).
				append(Node("Extends").append(yyDollar[4].node)).
				append(Node("Implements").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 218:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:696
		{
			yyVAL.node = Node("Class").
				attribute("name", yyDollar[2].token).
				append(Node("Extends").append(yyDollar[3].node)).
				append(Node("Implements").append(yyDollar[4].node)).
				append(yyDollar[6].node)
		}
	case 219:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:706
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 220:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:707
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 221:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:711
		{
			yyVAL.value = "abstract"
		}
	case 222:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:712
		{
			yyVAL.value = "final"
		}
	case 223:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:716
		{
			yyVAL.node = Node("Trait").attribute("name", yyDollar[2].token).append(yyDollar[4].node)
		}
	case 224:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:721
		{
			yyVAL.node = Node("Interface").
				attribute("name", yyDollar[2].token).
				append(Node("Extends").append(yyDollar[3].node)).
				append(yyDollar[5].node)
		}
	case 225:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:730
		{
			yyVAL.node = Node("")
		}
	case 226:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:731
		{
			yyVAL.node = yyDollar[2].node
		}
	case 227:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:735
		{
			yyVAL.node = Node("")
		}
	case 228:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:736
		{
			yyVAL.node = yyDollar[2].node
		}
	case 229:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:740
		{
			yyVAL.node = Node("")
		}
	case 230:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:741
		{
			yyVAL.node = yyDollar[2].node
		}
	case 231:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:745
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 232:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:746
		{
			yyVAL.node = Node("Stmt")
		}
	case 233:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:750
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 234:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:751
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[1].node)
		}
	case 235:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:752
		{
			yyVAL.node = Node("Use").append(yyDollar[2].node).append(yyDollar[3].node)
		}
	case 236:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:755
		{
			yyVAL.node = Node("Function").
				append(yyDollar[1].node).
				append(Node("name").append(yyDollar[4].node)).
				attribute("returns_ref", yyDollar[3].value).
				append(yyDollar[6].node).
				append(yyDollar[8].node).
				append(yyDollar[9].node)
		}
	case 237:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:767
		{
			yyVAL.node = Node("NameList").append(yyDollar[1].node)
		}
	case 238:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:768
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 239:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:772
		{
			yyVAL.node = Node("")
		}
	case 240:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:773
		{
			yyVAL.node = Node("")
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:774
		{
			yyVAL.node = yyDollar[2].node
		}
	case 242:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:778
		{
			yyVAL.node = Node("TraitAdaptionList").append(yyDollar[1].node)
		}
	case 243:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:779
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 244:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:783
		{
			yyVAL.node = yyDollar[1].node
		}
	case 245:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:784
		{
			yyVAL.node = yyDollar[1].node
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:789
		{
			yyVAL.node = Node("TraitPrecedence").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:793
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:795
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").append(Node("reservedNonModifiers")))
		}
	case 249:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:797
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 250:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:798
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 251:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:801
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node)
		}
	case 252:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:802
		{
			yyVAL.node = yyDollar[1].node
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:806
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 254:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:810
		{
			yyVAL.node = Node("")
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:811
		{
			yyVAL.node = yyDollar[2].node
		}
	case 256:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:815
		{
			yyVAL.node = yyDollar[1].node
		}
	case 257:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:816
		{
			yyVAL.node = Node("VarMemberModifier")
		}
	case 258:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:820
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 259:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:821
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:825
		{
			yyVAL.node = Node("Const").append(yyDollar[3].node)
		}
	case 261:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:829
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 262:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:830
		{
			yyVAL.node = yyDollar[1].node
		}
	case 263:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:833
		{
			yyVAL.node = yyDollar[1].node
		}
	case 264:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:834
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 265:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:837
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 266:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:838
		{
			yyVAL.node = Node("ProtectedMemberModifier")
		}
	case 267:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:839
		{
			yyVAL.node = Node("PrivateMemberModifier")
		}
	case 268:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:840
		{
			yyVAL.node = Node("StaticMemberModifier")
		}
	case 269:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:841
		{
			yyVAL.node = Node("AbstractMemberModifier")
		}
	case 270:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:842
		{
			yyVAL.node = Node("FinalMemberModifier")
		}
	case 271:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:846
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 272:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:847
		{
			yyVAL.node = Node("PropertyList").append(yyDollar[1].node)
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:850
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token)
		}
	case 274:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:851
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token).append(Node("Default").append(yyDollar[3].node))
		}
	case 275:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:856
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 276:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:867
		{
			yyVAL.node = yyDollar[1].node
		}
	case 277:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:868
		{
			yyVAL.node = Node("Parameter list")
		}
	case 278:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:871
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 279:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:872
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 280:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:876
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 281:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:884
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 282:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:895
		{
			yyVAL.node = Node("No type")
		}
	case 283:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:896
		{
			yyVAL.node = yyDollar[1].node
		}
	case 284:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:900
		{
			yyVAL.value = "false"
		}
	case 285:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:901
		{
			yyVAL.value = "true"
		}
	case 286:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:905
		{
			yyVAL.value = "false"
		}
	case 287:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:906
		{
			yyVAL.value = "true"
		}
	case 288:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:910
		{
			yyVAL.value = "false"
		}
	case 289:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:911
		{
			yyVAL.value = "true"
		}
	case 290:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:915
		{
			yyVAL.node = yyDollar[1].node
		}
	case 291:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:916
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 292:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:920
		{
			yyVAL.node = yyDollar[1].node
		}
	case 293:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:921
		{
			yyVAL.node = Node("array type")
		}
	case 294:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:922
		{
			yyVAL.node = Node("callable type")
		}
	case 295:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:926
		{
			yyVAL.node = Node("No return type")
		}
	case 296:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:927
		{
			yyVAL.node = yyDollar[2].node
		}
	case 297:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:931
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 298:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:932
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 299:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:933
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 300:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:934
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 301:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:935
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 302:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:936
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 303:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:937
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 304:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:938
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 305:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:939
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 306:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:940
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 307:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:941
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 308:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:942
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 309:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:943
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 310:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:944
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 311:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:945
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 312:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:946
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 313:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:947
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 314:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:948
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 315:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:949
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 316:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:950
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 317:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:951
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 318:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:952
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 319:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:953
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 320:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:954
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 321:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:955
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 322:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:956
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 323:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:957
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 324:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:958
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:959
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 326:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:960
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 327:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:961
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 328:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:962
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 329:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:963
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 330:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:964
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 331:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:965
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 332:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:966
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 333:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:967
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 334:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:968
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 335:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:969
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 336:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:970
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 337:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:971
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 338:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:972
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 339:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:973
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 340:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:974
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 341:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:975
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 342:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:976
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 343:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:977
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 344:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:978
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 345:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:979
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 346:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:980
		{
			yyVAL.node = yyDollar[2].node
		}
	case 347:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:981
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 348:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:982
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 349:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:983
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 350:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:984
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 351:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:985
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 352:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:986
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 353:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:987
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 354:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:988
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 355:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:989
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 356:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:990
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 357:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:991
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 358:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:992
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 359:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:993
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 360:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:994
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 361:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:995
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 362:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:996
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 363:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:997
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 364:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:998
		{
			yyVAL.node = yyDollar[1].node
		}
	case 365:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:999
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 366:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1000
		{
			yyVAL.node = Node("Yield")
		}
	case 367:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1001
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 368:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1002
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 369:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1003
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 370:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1007
		{
			yyVAL.node = Node("Scalar").append(Node("Lnumber").attribute("value", yyDollar[1].token))
		}
	case 371:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1008
		{
			yyVAL.node = Node("Scalar").append(Node("Dnumber").attribute("value", yyDollar[1].token))
		}
	case 372:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1009
		{
			yyVAL.node = Node("Scalar").append(Node("__LINE__"))
		}
	case 373:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1010
		{
			yyVAL.node = Node("Scalar").append(Node("__FILE__"))
		}
	case 374:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1011
		{
			yyVAL.node = Node("Scalar").append(Node("__DIR__"))
		}
	case 375:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1012
		{
			yyVAL.node = Node("Scalar").append(Node("__TRAIT__"))
		}
	case 376:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1013
		{
			yyVAL.node = Node("Scalar").append(Node("__METHOD__"))
		}
	case 377:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1014
		{
			yyVAL.node = Node("Scalar").append(Node("__FUNCTION__"))
		}
	case 378:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1015
		{
			yyVAL.node = Node("Scalar").append(Node("__NAMESPACE__"))
		}
	case 379:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1016
		{
			yyVAL.node = Node("Scalar").append(Node("__CLASS__"))
		}
	case 380:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1018
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc").attribute("value", yyDollar[2].token))
		}
	case 381:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1020
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc"))
		}
	case 382:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1021
		{
			yyVAL.node = yyDollar[2].node
		}
	case 383:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1022
		{
			yyVAL.node = yyDollar[2].node
		}
	case 384:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1023
		{
			yyVAL.node = yyDollar[1].node
		}
	case 385:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1024
		{
			yyVAL.node = yyDollar[1].node
		}
	case 386:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1028
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 387:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1029
		{
			yyVAL.node = yyDollar[1].node.append(Node("String").attribute("value", yyDollar[2].token))
		}
	case 388:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1030
		{
			yyVAL.node = Node("EncapsList").append(yyDollar[1].node)
		}
	case 389:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1031
		{
			yyVAL.node = Node("EncapsList").append(Node("String").attribute("value", yyDollar[1].token)).append(yyDollar[2].node)
		}
	case 390:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1034
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token)
		}
	case 391:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1035
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("offset").append(yyDollar[3].node))
		}
	case 392:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1036
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("property").attribute("value", yyDollar[3].token))
		}
	case 393:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1037
		{
			yyVAL.node = Node("Variable").append(Node("expr").append(yyDollar[2].node))
		}
	case 394:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1038
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token)
		}
	case 395:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:1040
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token).append(Node("offset").append(yyDollar[4].node))
		}
	case 396:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1041
		{
			yyVAL.node = yyDollar[2].node
		}
	case 397:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1044
		{
			yyVAL.node = Node("OffsetString").attribute("value", yyDollar[1].token)
		}
	case 398:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1045
		{
			yyVAL.node = Node("OffsetNumString").attribute("value", yyDollar[1].token)
		}
	case 399:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1046
		{
			yyVAL.node = Node("OffsetNegateNumString").attribute("value", yyDollar[2].token)
		}
	case 400:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1047
		{
			yyVAL.node = Node("OffsetVariable").attribute("value", yyDollar[1].token)
		}
	case 401:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1051
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node)
		}
	case 402:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1052
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 403:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1054
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 404:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1058
		{
			yyVAL.node = Node("Static")
		}
	case 405:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1059
		{
			yyVAL.node = yyDollar[1].node
		}
	case 406:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1063
		{
			yyVAL.node = yyDollar[1].node
		}
	case 407:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1067
		{
			yyVAL.node = yyDollar[1].node
		}
	case 408:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1068
		{
			yyVAL.node = yyDollar[2].node
		}
	case 409:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1069
		{
			yyVAL.node = yyDollar[1].node
		}
	case 410:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1073
		{
			yyVAL.node = yyDollar[1].node
		}
	case 411:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1074
		{
			yyVAL.node = yyDollar[2].node
		}
	case 412:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1075
		{
			yyVAL.node = yyDollar[1].node
		}
	case 413:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1079
		{
			yyVAL.node = yyDollar[3].node
		}
	case 414:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1080
		{
			yyVAL.node = yyDollar[2].node
		}
	case 415:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1081
		{
			yyVAL.node = Node("String").attribute("value", yyDollar[1].token)
		}
	case 416:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1085
		{
			yyVAL.node = yyDollar[1].node
		}
	case 417:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1086
		{
			yyVAL.node = yyDollar[1].node
		}
	case 418:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1090
		{
			yyVAL.node = Node("")
		}
	case 419:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1091
		{
			yyVAL.node = yyDollar[1].node
		}
	case 420:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1095
		{
			yyVAL.node = yyDollar[1].node
		}
	case 421:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1096
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 422:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1097
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 423:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1098
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 424:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1100
		{
			yyVAL.node = Node("MethodCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 425:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1101
		{
			yyVAL.node = yyDollar[1].node
		}
	case 426:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1105
		{
			yyVAL.node = Node("FunctionCall").append(yyDollar[1].node).append(yyDollar[2].node)
		}
	case 427:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1107
		{
			yyVAL.node = Node("StaticCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 428:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1109
		{
			yyVAL.node = Node("StaticCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 429:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1110
		{
			yyVAL.node = Node("Call").append(yyDollar[1].node).append(yyDollar[2].node)
		}
	case 430:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1114
		{
			yyVAL.node = yyDollar[1].node
		}
	case 431:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1115
		{
			yyVAL.node = yyDollar[2].node
		}
	case 432:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1116
		{
			yyVAL.node = yyDollar[1].node
		}
	case 433:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1120
		{
			yyVAL.node = Node("ArgumentList")
		}
	case 434:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1121
		{
			yyVAL.node = yyDollar[2].node
		}
	case 435:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1124
		{
			yyVAL.node = Node("ArgumentList").append(yyDollar[1].node)
		}
	case 436:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1125
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 437:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1128
		{
			yyVAL.node = yyDollar[1].node
		}
	case 438:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1129
		{
			yyVAL.node = Node("Unpack").append(yyDollar[2].node)
		}
	case 439:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1133
		{
			yyVAL.node = yyDollar[1].node
		}
	case 440:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1134
		{
			yyVAL.node = yyDollar[1].node
		}
	case 441:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1135
		{
			yyVAL.node = Node("Property").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 442:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1139
		{
			yyVAL.node = Node("PropertyName").attribute("value", yyDollar[1].token)
		}
	case 443:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1140
		{
			yyVAL.node = yyDollar[2].node
		}
	case 444:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1141
		{
			yyVAL.node = yyDollar[1].node
		}
	case 445:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1145
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 446:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1146
		{
			yyVAL.node = Node("Variable").append(yyDollar[3].node)
		}
	case 447:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1147
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	case 448:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1152
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 449:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1154
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	}
	goto yystack /* stack new state and value */
}
